"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sequelize_1 = require("sequelize");
module.exports = (sequelize, DataTypes) => {
    class Customer extends sequelize_1.Model {
        static associate(models) {
            // A Customer belongs to a Tailor
            Customer.belongsTo(models.Tailor, {
                foreignKey: 'tailorId',
                as: 'tailor',
            });
            // A Customer has many Measurements
            Customer.hasMany(models.Measurement, {
                foreignKey: 'customerId',
                as: 'measurements',
            });
        }
    }
    Customer.init({
        id: {
            type: DataTypes.UUID,
            primaryKey: true,
            defaultValue: DataTypes.UUIDV4,
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
        },
        email: {
            type: DataTypes.STRING,
            allowNull: true,
            validate: { isEmail: true },
        },
        phone: {
            type: DataTypes.STRING,
            allowNull: true,
            validate: { is: /^[0-9\-+]+$/ },
        },
        tailorId: {
            type: DataTypes.UUID,
            allowNull: false,
            references: {
                model: 'tailors',
                key: 'id',
            },
        },
    }, {
        sequelize,
        modelName: 'Customer',
        tableName: 'customers',
        underscored: true,
        timestamps: true,
    });
    return Customer;
};
//# sourceMappingURL=customer.js.map