"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const moment_1 = __importDefault(require("moment"));
const logger_1 = __importDefault(require("./logger"));
const httpLogger = (req, res, next) => {
    const { method, url, headers } = req;
    // Filter headers
    const filteredHeaders = Object.assign({}, headers);
    delete filteredHeaders.authorization;
    // Get response time
    const start = process.hrtime();
    res.on("finish", () => {
        const elapsed = process.hrtime(start)[1] / 1000000;
        const responseTime = elapsed.toFixed(3);
        // Get IP address
        const ip = req.headers["x-forwarded-for"] || req.socket.remoteAddress || null;
        // Build log data
        const logData = {
            timestamp: (0, moment_1.default)().format(),
            ip,
            method,
            url,
            headers: filteredHeaders,
            statusCode: res.statusCode,
            responseTime: `${responseTime}ms`,
        };
        logger_1.default.info("HTTP Request Log", logData);
    });
    next();
};
exports.default = httpLogger;
//# sourceMappingURL=httpLogger.js.map