"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAdmin = exports.apiKeyAuthMiddleware = exports.protect = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const express_async_handler_1 = __importDefault(require("express-async-handler"));
const error_1 = require("../error");
const config_1 = __importDefault(require("../config"));
const jwt_user_1 = require("../utils/jwt-user");
const models_1 = __importDefault(require("../database/models"));
const logger_1 = __importDefault(require("../logger"));
const { Tailor } = models_1.default;
exports.protect = (0, express_async_handler_1.default)((request, response, next) => __awaiter(void 0, void 0, void 0, function* () {
    const token = getAuthToken(request);
    const decodedValue = decodeToken(token);
    response.locals.user = new jwt_user_1.JWTUser(decodedValue);
    logger_1.default.info(`User ${response.locals.user.getId()} accessed ${request.url} route`);
    next();
}));
function getAuthToken(request) {
    let token = request.headers["authorization"];
    if (token === null || token === void 0 ? void 0 : token.startsWith("Bearer ")) {
        token = token.split(" ")[1];
    }
    if (!token) {
        throw (0, error_1.authenticationError)("Auth token is required");
    }
    return token;
}
function decodeToken(token) {
    try {
        const decodedToken = jsonwebtoken_1.default.verify(token, config_1.default.auth.secretToken);
        return decodedToken;
    }
    catch (error) {
        throw (0, error_1.authenticationError)("Error occured while validating token");
    }
}
const apiKeyAuthMiddleware = (request, response, next) => {
    const receivedApiKey = request.get("x-api-key");
    if (!receivedApiKey || receivedApiKey !== config_1.default.auth.apiKey) {
        throw (0, error_1.authenticationError)("Unauthorized. API key is missing or invalid");
    }
    next();
};
exports.apiKeyAuthMiddleware = apiKeyAuthMiddleware;
exports.isAdmin = (0, express_async_handler_1.default)((request, response, next) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    if (!user.getIsAdmin()) {
        throw (0, error_1.authorizationError)("Access denied.");
    }
    next();
}));
//# sourceMappingURL=authenticate.js.map