"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.customerRoutes = void 0;
const celebrate_1 = require("celebrate");
const express_1 = require("express");
const express_async_handler_1 = __importDefault(require("express-async-handler"));
const customer_1 = __importDefault(require("../../controllers/customer"));
const authenticate_1 = require("../../middlewares/authenticate");
const validation_schema_1 = require("../../utils/validation-schema");
const customerRoutes = (0, express_1.Router)();
exports.customerRoutes = customerRoutes;
const customerController = new customer_1.default();
// customerRoutes.get(
//   "/",
//   apiKeyAuthMiddleware,
//   protect,
//   celebrate({ query: customerQuerySchema }),
//   asyncHandler(async (request: Request, response: Response) => {
//     const user = response.locals.user as JWTUser;
//     const tailorId = user.id;
//     const query = request.query;
//     const data = await customerController.getCustomers(tailorId, query);
//     response.status(200).json(data).end();
//   })
// );
customerRoutes.get("/", authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ query: validation_schema_1.customerQuerySchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const _a = request.query, { page, limit } = _a, query = __rest(_a, ["page", "limit"]);
    const data = yield customerController.getCustomers(tailorId, query, Number(page), Number(limit));
    response.status(200).json(data).end();
})));
customerRoutes.get("/:id", authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ params: validation_schema_1.viewCustomerDetailsSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { id } = request.params;
    const data = yield customerController.viewCustomerDetails(tailorId, id);
    response.status(200).json(data).end();
})));
customerRoutes.post("/", authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ body: validation_schema_1.createCustomerSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const customerData = request.body;
    const data = yield customerController.createCustomer(tailorId, customerData);
    response.status(201).json(data).end();
})));
customerRoutes.put("/:id", authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ body: validation_schema_1.updateCustomerSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { id } = request.params;
    const customerData = request.body;
    const data = yield customerController.updateCustomer(tailorId, id, customerData);
    response.status(200).json(data).end();
})));
//# sourceMappingURL=customer.js.map