"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.measurementRoutes = void 0;
const celebrate_1 = require("celebrate");
const express_1 = require("express");
const express_async_handler_1 = __importDefault(require("express-async-handler"));
const measurement_1 = __importDefault(require("../../controllers/measurement"));
const authenticate_1 = require("../../middlewares/authenticate");
const validation_schema_1 = require("../../utils/validation-schema");
const measurementRoutes = (0, express_1.Router)();
exports.measurementRoutes = measurementRoutes;
const measurementController = new measurement_1.default();
measurementRoutes.get('/:customerId', authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ params: validation_schema_1.viewMeasurementsSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { customerId } = request.params;
    const data = yield measurementController.getMeasurements(tailorId, customerId);
    response.status(200).json(data).end();
})));
measurementRoutes.get('/details/:id', authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ params: validation_schema_1.viewMeasurementDetailsSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { id } = request.params;
    const data = yield measurementController.viewMeasurementDetails(tailorId, id);
    response.status(200).json(data).end();
})));
measurementRoutes.post('/', authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ body: validation_schema_1.createMeasurementSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const measurementData = request.body;
    const data = yield measurementController.createMeasurement(tailorId, measurementData);
    response.status(201).json(data).end();
})));
measurementRoutes.put('/:id', authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, celebrate_1.celebrate)({ body: validation_schema_1.updateMeasurementSchema }), (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { id } = request.params;
    const measurementData = request.body;
    const data = yield measurementController.updateMeasurement(tailorId, id, measurementData);
    response.status(200).json(data).end();
})));
measurementRoutes.delete('/:id', authenticate_1.apiKeyAuthMiddleware, authenticate_1.protect, (0, express_async_handler_1.default)((request, response) => __awaiter(void 0, void 0, void 0, function* () {
    const user = response.locals.user;
    const tailorId = user.id;
    const { id } = request.params;
    const data = yield measurementController.deleteMeasurement(tailorId, id);
    response.status(200).json(data).end();
})));
//# sourceMappingURL=measurement.js.map