"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
const logger_1 = __importDefault(require("./logger"));
const express_1 = __importDefault(require("express"));
const cors_1 = __importDefault(require("cors"));
const helmet_1 = __importDefault(require("helmet"));
const index_1 = __importDefault(require("./database/models/index"));
const routes_1 = require("./routes");
const error_1 = require("./error");
const httpLogger_1 = __importDefault(require("./httpLogger"));
const app = (0, express_1.default)();
const PORT = 3000;
app.set("trust proxy", true);
app.use((0, helmet_1.default)());
app.use(express_1.default.json());
app.use((0, cors_1.default)());
app.use(httpLogger_1.default);
app.use(routes_1.routes);
process.on("uncaughtException", (err) => {
    // eslint-disable-next-line no-console
    logger_1.default.error("UNCAUGHT EXCEPTION! 💥 Shutting down...");
    logger_1.default.error(err);
    logger_1.default.error(err.name, err.message);
    process.exit(1);
});
app.get("/actuator/health", (request, response) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield index_1.default.sequelize.authenticate().then(() => {
            logger_1.default.info("Connected to database!");
        });
        response.status(200).json({
            message: "Server Okay and database connection OK",
            info: {
                url: `${request.protocol}://${request.hostname}${request.path}`,
            },
        });
    }
    catch (error) {
        response.status(500).json({
            message: "Database connection failed",
            error: error.message,
            info: {
                url: `${request.protocol}://${request.hostname}${request.path}`,
            },
        });
    }
}));
// capture all 404 errors
app.use(function (request, response) {
    logger_1.default.error(`Route not found: ${request.path}`);
    throw (0, error_1.unknownResourceError)(`The route you are trying to reach (${request.path}) does not exist`);
});
app.use((err, req, res, next) => {
    (0, error_1.handleError)(err, res);
});
app.listen(PORT, () => {
    logger_1.default.info(`App is listening on port ${PORT}`);
});
//# sourceMappingURL=server.js.map