"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sequelize_1 = require("sequelize");
const models_1 = __importDefault(require("../database/models/"));
const error_1 = require("../error");
const { Customer, Measurement } = models_1.default;
class CustomerService {
    getCustomers(tailorId_1, query_1) {
        return __awaiter(this, arguments, void 0, function* (tailorId, query, page = 1, limit = 10) {
            const { name, email, phone } = query;
            const whereClause = { tailorId };
            if (name) {
                whereClause.name = { [sequelize_1.Op.iLike]: `%${name}%` };
            }
            if (email) {
                whereClause.email = { [sequelize_1.Op.iLike]: `%${email}%` };
            }
            if (phone) {
                whereClause.phone = { [sequelize_1.Op.iLike]: `%${phone}%` };
            }
            const offset = (page - 1) * limit;
            const customers = yield Customer.findAndCountAll({
                where: whereClause,
                limit,
                offset,
            });
            return {
                data: customers.rows,
                total: customers.count,
                page,
                totalPages: Math.ceil(customers.count / limit),
            };
        });
    }
    viewCustomerDetails(tailorId, id) {
        return __awaiter(this, void 0, void 0, function* () {
            const customer = yield Customer.findOne({
                where: {
                    id,
                    tailorId,
                },
                include: [{
                        model: Measurement,
                        as: 'measurements',
                        attributes: { exclude: ['tailorId'] },
                    }],
            });
            if (!customer) {
                throw (0, error_1.unknownResourceError)('Customer not found or access denied');
            }
            return customer;
        });
    }
    createCustomer(tailorId, input) {
        return __awaiter(this, void 0, void 0, function* () {
            const { name, email, phone } = input;
            const customer = yield Customer.create({
                name,
                email,
                phone,
                tailorId,
            });
            return customer;
        });
    }
    updateCustomer(tailorId, id, input) {
        return __awaiter(this, void 0, void 0, function* () {
            const customer = yield Customer.findOne({
                where: {
                    id,
                    tailorId,
                }
            });
            if (!customer) {
                throw (0, error_1.unknownResourceError)('Customer not found or access denied');
            }
            yield customer.update(input);
            return customer;
        });
    }
}
exports.default = CustomerService;
//# sourceMappingURL=customer.js.map