"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = __importDefault(require("../database/models/"));
const error_1 = require("../error");
const { Measurement, Customer } = models_1.default;
class MeasurementService {
    getMeasurements(tailorId, customerId) {
        return __awaiter(this, void 0, void 0, function* () {
            const customer = yield Customer.findOne({ where: { id: customerId, tailorId } });
            if (!customer) {
                throw (0, error_1.authorizationError)('Access denied. Customer does not belong to this tailor.');
            }
            const measurements = yield Measurement.findAll({
                where: { customerId },
            });
            return measurements;
        });
    }
    viewMeasurementDetails(tailorId, id) {
        return __awaiter(this, void 0, void 0, function* () {
            const measurement = yield Measurement.findByPk(id, {
                include: [{ model: Customer, as: 'customer' }],
            });
            if (!measurement || measurement.customer.tailorId !== tailorId) {
                throw (0, error_1.unknownResourceError)('Measurement not found or access denied.');
            }
            return measurement;
        });
    }
    createMeasurement(tailorId, input) {
        return __awaiter(this, void 0, void 0, function* () {
            const { customerId } = input;
            const customer = yield Customer.findOne({ where: { id: customerId, tailorId } });
            if (!customer) {
                throw (0, error_1.authorizationError)('Access denied. Cannot create measurement for this customer.');
            }
            const measurement = yield Measurement.create(input);
            return measurement;
        });
    }
    updateMeasurement(tailorId, id, input) {
        return __awaiter(this, void 0, void 0, function* () {
            const measurement = yield Measurement.findByPk(id, {
                include: [{ model: Customer, as: 'customer' }],
            });
            if (!measurement || measurement.customer.tailorId !== tailorId) {
                throw (0, error_1.unknownResourceError)('Measurement not found or access denied.');
            }
            yield measurement.update(input);
            return measurement;
        });
    }
    deleteMeasurement(tailorId, id) {
        return __awaiter(this, void 0, void 0, function* () {
            const measurement = yield Measurement.findByPk(id, {
                include: [{ model: Customer, as: 'customer' }],
            });
            if (!measurement || measurement.customer.tailorId !== tailorId) {
                throw (0, error_1.unknownResourceError)('Measurement not found or access denied.');
            }
            yield measurement.destroy();
            return { message: 'Measurement deleted successfully' };
        });
    }
}
exports.default = MeasurementService;
//# sourceMappingURL=measurement.js.map