"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const bcrypt_1 = __importDefault(require("bcrypt"));
const models_1 = __importDefault(require("../database/models"));
const error_1 = require("../error");
const config_1 = __importDefault(require("../config"));
const { Tailor } = models_1.default;
class TailorService {
    register(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const { email, name, password } = input;
            // Check if email already exists
            const emailExist = yield Tailor.findOne({ where: { email } });
            if (emailExist) {
                throw (0, error_1.badRequestError)("Email address already exists, please login to continue.");
            }
            const salt = yield bcrypt_1.default.genSalt(10);
            const hashedPassword = yield bcrypt_1.default.hash(password, salt);
            // Create new Tailor
            const tailor = yield Tailor.create({
                email,
                name,
                password: hashedPassword,
            });
            // Generate access and refresh tokens
            const accessToken = jsonwebtoken_1.default.sign({ id: tailor.id }, // Assuming tailors are not admins by default
            config_1.default.auth.secretToken, {
                expiresIn: config_1.default.auth.tokenExpiration,
            });
            return {
                user: {
                    id: tailor.id,
                    name: tailor.name,
                    email: tailor.email,
                },
                accessToken
            };
        });
    }
    login(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const { email, password } = input;
            // Find tailor by email
            const tailor = yield Tailor.findOne({
                where: {
                    email,
                },
            });
            // Check if tailor exists
            if (!tailor) {
                throw (0, error_1.badRequestError)("Email or Password is incorrect.");
            }
            // Verify password
            const verifyCredentials = bcrypt_1.default.compareSync(password, tailor.password);
            if (!verifyCredentials) {
                throw (0, error_1.badRequestError)("Email or Password is incorrect.");
            }
            // Generate access and refresh tokens
            const accessToken = jsonwebtoken_1.default.sign({ id: tailor.id, isAdmin: false }, // Assuming tailors are not admins by default
            config_1.default.auth.secretToken, {
                expiresIn: config_1.default.auth.tokenExpiration,
            });
            // Update last login time
            tailor.lastLoginAt = new Date();
            yield tailor.save();
            return {
                user: {
                    id: tailor.id,
                    name: tailor.name,
                    email: tailor.email,
                },
                accessToken,
            };
        });
    }
    changePassword(input, tailorId) {
        return __awaiter(this, void 0, void 0, function* () {
            const { oldPassword, newPassword } = input;
            const tailor = yield Tailor.findOne({ _id: tailorId });
            if (!tailor) {
                throw (0, error_1.badRequestError)("Tailor not found");
            }
            const verifyCredentials = yield bcrypt_1.default.compare(oldPassword, tailor.password);
            if (!verifyCredentials) {
                throw (0, error_1.badRequestError)("Incorrect current password");
            }
            const isPasswordDifferent = yield bcrypt_1.default.compare(newPassword, tailor.password);
            if (isPasswordDifferent) {
                throw (0, error_1.badRequestError)("New password must be different from previous password");
            }
            const salt = yield bcrypt_1.default.genSalt(10);
            tailor.password = yield bcrypt_1.default.hash(newPassword, salt);
            yield tailor.save();
        });
    }
}
exports.default = TailorService;
//# sourceMappingURL=tailor.js.map