"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.viewMeasurementsSchema = exports.viewMeasurementDetailsSchema = exports.updateMeasurementSchema = exports.createMeasurementSchema = exports.viewCustomerDetailsSchema = exports.customerQuerySchema = exports.updateCustomerSchema = exports.createCustomerSchema = exports.refreshTokenSchema = exports.loginSchema = exports.changePasswordSchema = exports.registerAccountSchema = void 0;
const celebrate_1 = require("celebrate");
exports.registerAccountSchema = celebrate_1.Joi.object({
    name: celebrate_1.Joi.string().trim().required(),
    email: celebrate_1.Joi.string().trim().email().lowercase().required(),
    password: celebrate_1.Joi.string()
        .min(8)
        .messages({ 'string.min': '"password" must be at least 8 characters long' }),
});
exports.changePasswordSchema = celebrate_1.Joi.object().keys({
    oldPassword: celebrate_1.Joi.string()
        .required()
        .messages({ 'any.required': '"oldPassword" is required' }),
    newPassword: celebrate_1.Joi.string()
        .min(8)
        .messages({ 'string.min': '"newPassword" must be at least 8 characters long' })
        .required(),
});
exports.loginSchema = celebrate_1.Joi.object().keys({
    email: celebrate_1.Joi.string().trim().email().lowercase().required(),
    password: celebrate_1.Joi.string().required(),
});
exports.refreshTokenSchema = celebrate_1.Joi.object().keys({
    refreshToken: celebrate_1.Joi.string().required(),
});
exports.createCustomerSchema = celebrate_1.Joi.object({
    name: celebrate_1.Joi.string().required(),
    email: celebrate_1.Joi.string().email().allow(null).optional(), // Allows null
    phone: celebrate_1.Joi.string().allow(null).optional(), // Allows null
});
exports.updateCustomerSchema = celebrate_1.Joi.object({
    name: celebrate_1.Joi.string().optional(),
    email: celebrate_1.Joi.string().email().allow(null).optional(),
    phone: celebrate_1.Joi.string().allow(null).optional(),
});
exports.customerQuerySchema = celebrate_1.Joi.object({
    name: celebrate_1.Joi.string().optional(),
    email: celebrate_1.Joi.string().email().optional(),
    phone: celebrate_1.Joi.string().optional(),
    page: celebrate_1.Joi.number().integer().min(1).optional(), // Allow page as an optional parameter
    limit: celebrate_1.Joi.number().integer().min(1).optional(),
});
exports.viewCustomerDetailsSchema = celebrate_1.Joi.object({
    id: celebrate_1.Joi.string().uuid().required(),
});
exports.createMeasurementSchema = celebrate_1.Joi.object({
    customerId: celebrate_1.Joi.string().uuid().required(),
    back: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    neck: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    chest: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    stomach: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    arm: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    shortSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    longSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    lengthOfTop: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    threeQuarterSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    waist: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    thigh: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    lengthOfPant: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    calf: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    kneel: celebrate_1.Joi.number().allow(null).optional(), // Allows null
});
exports.updateMeasurementSchema = celebrate_1.Joi.object({
    back: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    neck: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    chest: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    stomach: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    arm: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    shortSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    longSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    lengthOfTop: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    threeQuarterSleeve: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    waist: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    thigh: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    lengthOfPant: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    calf: celebrate_1.Joi.number().allow(null).optional(), // Allows null
    kneel: celebrate_1.Joi.number().allow(null).optional(), // Allows null
});
exports.viewMeasurementDetailsSchema = celebrate_1.Joi.object({
    id: celebrate_1.Joi.string().uuid().required(),
});
exports.viewMeasurementsSchema = celebrate_1.Joi.object({
    customerId: celebrate_1.Joi.string().uuid().required(),
});
//# sourceMappingURL=validation-schema.js.map